==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/WellKnownOrgMetadataLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * WellKnownOrgMetadataLinks
 */
@JsonPropertyOrder({ WellKnownOrgMetadataLinks.JSON_PROPERTY_ALTERNATE,
        WellKnownOrgMetadataLinks.JSON_PROPERTY_ORGANIZATION })
@JsonTypeName("WellKnownOrgMetadata__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class WellKnownOrgMetadataLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALTERNATE = "alternate";
    private HrefObject alternate;

    public static final String JSON_PROPERTY_ORGANIZATION = "organization";
    private HrefObject organization;

    public WellKnownOrgMetadataLinks() {
    }

    public WellKnownOrgMetadataLinks alternate(HrefObject alternate) {

        this.alternate = alternate;
        return this;
    }

    /**
     * Get alternate
     *
     * @return alternate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALTERNATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getAlternate() {
        return alternate;
    }

    @JsonProperty(JSON_PROPERTY_ALTERNATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAlternate(HrefObject alternate) {
        this.alternate = alternate;
    }

    public WellKnownOrgMetadataLinks organization(HrefObject organization) {

        this.organization = organization;
        return this;
    }

    /**
     * Get organization
     *
     * @return organization
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ORGANIZATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getOrganization() {
        return organization;
    }

    @JsonProperty(JSON_PROPERTY_ORGANIZATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOrganization(HrefObject organization) {
        this.organization = organization;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        WellKnownOrgMetadataLinks wellKnownOrgMetadataLinks = (WellKnownOrgMetadataLinks) o;
        return Objects.equals(this.alternate, wellKnownOrgMetadataLinks.alternate)
                && Objects.equals(this.organization, wellKnownOrgMetadataLinks.organization);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(alternate, organization);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class WellKnownOrgMetadataLinks {\n");
        sb.append("    alternate: ").append(toIndentedString(alternate)).append("\n");
        sb.append("    organization: ").append(toIndentedString(organization)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/WellKnownOrgMetadataLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * WellKnownOrgMetadataLinks
 */
@JsonPropertyOrder({ WellKnownOrgMetadataLinks.JSON_PROPERTY_ALTERNATE,
        WellKnownOrgMetadataLinks.JSON_PROPERTY_ORGANIZATION })
@JsonTypeName("WellKnownOrgMetadata__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class WellKnownOrgMetadataLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALTERNATE = "alternate";
    private HrefObject alternate;

    public static final String JSON_PROPERTY_ORGANIZATION = "organization";
    private HrefObject organization;

    public WellKnownOrgMetadataLinks() {
    }

    public WellKnownOrgMetadataLinks alternate(HrefObject alternate) {

        this.alternate = alternate;
        return this;
    }

    /**
     * Get alternate
     *
     * @return alternate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALTERNATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getAlternate() {
        return alternate;
    }

    @JsonProperty(JSON_PROPERTY_ALTERNATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAlternate(HrefObject alternate) {
        this.alternate = alternate;
    }

    public WellKnownOrgMetadataLinks organization(HrefObject organization) {

        this.organization = organization;
        return this;
    }

    /**
     * Get organization
     *
     * @return organization
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ORGANIZATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getOrganization() {
        return organization;
    }

    @JsonProperty(JSON_PROPERTY_ORGANIZATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOrganization(HrefObject organization) {
        this.organization = organization;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        WellKnownOrgMetadataLinks wellKnownOrgMetadataLinks = (WellKnownOrgMetadataLinks) o;
        return Objects.equals(this.alternate, wellKnownOrgMetadataLinks.alternate)
                && Objects.equals(this.organization, wellKnownOrgMetadataLinks.organization);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(alternate, organization);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class WellKnownOrgMetadataLinks {\n");
        sb.append("    alternate: ").append(toIndentedString(alternate)).append("\n");
        sb.append("    organization: ").append(toIndentedString(organization)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
